[Python-checkins] cpython (merge 3.3 -> default): merge #15889: make regrtest --start succeed in more cases.

r.david.murray python-checkins at python.org
Sat Oct 27 23:10:26 CEST 2012


http://hg.python.org/cpython/rev/f9bd7633316c
changeset:   79991:f9bd7633316c
parent:      79988:fd3bc0323505
parent:      79990:19f205e3111c
user:        R David Murray <rdmurray at bitdance.com>
date:        Sat Oct 27 17:09:37 2012 -0400
summary:
  merge #15889: make regrtest --start succeed in more cases.

Patch by Chris Jerdonek.

files:
  Lib/test/regrtest.py |  4 ++--
  1 files changed, 2 insertions(+), 2 deletions(-)


diff --git a/Lib/test/regrtest.py b/Lib/test/regrtest.py
--- a/Lib/test/regrtest.py
+++ b/Lib/test/regrtest.py
@@ -556,10 +556,10 @@
             next_single_test = alltests[alltests.index(selected[0])+1]
         except IndexError:
             next_single_test = None
     # Remove all the tests that precede start if it's set.
     if start:
         try:
-            del tests[:tests.index(start)]
+            del selected[:selected.index(start)]
         except ValueError:
             print("Couldn't find starting test (%s), using all tests" % start)
     if randomize:
@@ -556,10 +556,10 @@
         except IndexError:
             next_single_test = None
-    # Remove all the tests that precede start if it's set.
+    # Remove all the selected tests that precede start if it's set.
     if start:
         try:

-- 
Repository URL: http://hg.python.org/cpython


More information about the Python-checkins mailing list